==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/DependenceTag.h <==
// public class soot.jimple.toolkits.pointer.DependenceTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fc56102dae3e43c0 soot_jimple_toolkits_pointer_DependenceTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_DependenceTag_H_
#define _JC_soot_jimple_toolkits_pointer_DependenceTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_refs	_jc_soot_jimple_toolkits_pointer_DependenceTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$refs	_jc_soot_jimple_toolkits_pointer_DependenceTag$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object	_jc_soot_jimple_toolkits_pointer_DependenceTag$object;

typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$fields_struct	_jc_soot_jimple_toolkits_pointer_DependenceTag$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vmethods	_jc_soot_jimple_toolkits_pointer_DependenceTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vtable	_jc_soot_jimple_toolkits_pointer_DependenceTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vtype	_jc_soot_jimple_toolkits_pointer_DependenceTag$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_pointer_DependenceTag$fields_struct _jc_soot_jimple_toolkits_pointer_DependenceTag$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_DependenceTag$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_DependenceTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *);
extern _jc_byte_array *_jc_soot_jimple_toolkits_pointer_DependenceTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *);
extern jboolean _jc_soot_jimple_toolkits_pointer_DependenceTag$method$setCallsNative$5ebad70a13ab07e3(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *);
extern void _jc_soot_jimple_toolkits_pointer_DependenceTag$method$setRead$9e260522deb8e863(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *, jshort);
extern void _jc_soot_jimple_toolkits_pointer_DependenceTag$method$setWrite$34104ba66327272f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *, jshort);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_DependenceTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$setCallsNative$5ebad70a13ab07e3;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$setRead$9e260522deb8e863;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$setWrite$34104ba66327272f;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *);
	jboolean	(*setCallsNative$5ebad70a13ab07e3)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *);
	void	(*setRead$9e260522deb8e863)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *, jshort);
	void	(*setWrite$34104ba66327272f)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *, jshort);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_DependenceTag$vmethods	soot_jimple_toolkits_pointer_DependenceTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_DependenceTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$refs {
    _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_refs	soot_jimple_toolkits_pointer_DependenceTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_nonrefs {
	jshort	read;
	jshort	write;
	jboolean	callsNative;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_nonrefs	soot_jimple_toolkits_pointer_DependenceTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object {
	_jc_soot_jimple_toolkits_pointer_DependenceTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_DependenceTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_DependenceTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_DependenceTag$vtype _jc_soot_jimple_toolkits_pointer_DependenceTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_DependenceTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_DependenceTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_DependenceTag_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/DependenceTag.h <==
// public class soot.jimple.toolkits.pointer.DependenceTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fc56102dae3e43c0 soot_jimple_toolkits_pointer_DependenceTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_DependenceTag_H_
#define _JC_soot_jimple_toolkits_pointer_DependenceTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_refs	_jc_soot_jimple_toolkits_pointer_DependenceTag$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceTag$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$refs	_jc_soot_jimple_toolkits_pointer_DependenceTag$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$nonrefs	_jc_soot_jimple_toolkits_pointer_DependenceTag$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object	_jc_soot_jimple_toolkits_pointer_DependenceTag$object;

typedef struct _jc_soot_jimple_toolkits_pointer_DependenceTag$fields_struct	_jc_soot_jimple_toolkits_pointer_DependenceTag$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vmethods	_jc_soot_jimple_toolkits_pointer_DependenceTag$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vtable	_jc_soot_jimple_toolkits_pointer_DependenceTag$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vtype	_jc_soot_jimple_toolkits_pointer_DependenceTag$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$fields_struct {
	struct _jc_java_lang_String$object	*NAME;
};
extern _jc_soot_jimple_toolkits_pointer_DependenceTag$fields_struct _jc_soot_jimple_toolkits_pointer_DependenceTag$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_DependenceTag$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_DependenceTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_jimple_toolkits_pointer_DependenceTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_pointer_DependenceTag$method$setCallsNative$5ebad70a13ab07e3(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_DependenceTag$method$setRead$9e260522deb8e863(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *, jshort) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_DependenceTag$method$setWrite$34104ba66327272f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *, jshort) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_DependenceTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$setCallsNative$5ebad70a13ab07e3;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$setRead$9e260522deb8e863;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$setWrite$34104ba66327272f;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DependenceTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *) _JC_JCNI_ATTR;
	jboolean	(*setCallsNative$5ebad70a13ab07e3)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *) _JC_JCNI_ATTR;
	void	(*setRead$9e260522deb8e863)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *, jshort) _JC_JCNI_ATTR;
	void	(*setWrite$34104ba66327272f)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *, jshort) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_DependenceTag$vmethods	soot_jimple_toolkits_pointer_DependenceTag;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_DependenceTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$refs {
    _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_refs	soot_jimple_toolkits_pointer_DependenceTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_nonrefs {
	jshort	read;
	jshort	write;
	jboolean	callsNative;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_DependenceTag$sub_nonrefs	soot_jimple_toolkits_pointer_DependenceTag;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_DependenceTag$object {
	_jc_soot_jimple_toolkits_pointer_DependenceTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_DependenceTag$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_DependenceTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_DependenceTag$vtype _jc_soot_jimple_toolkits_pointer_DependenceTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_DependenceTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_DependenceTag$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_DependenceTag_H_ */
